@@ -1,17 +1,14 @@
 /*
- * $Id: MessageHeaderExpressionEvaluator.java 20092 2010-11-05 19:17:25Z aperepel $
- * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
- *
  * The software in this package is published under the terms of the CPAL v1.0
  * license, a copy of which has been included with this distribution in the
  * LICENSE.txt file.
  */
-
 package org.mule.expression;
 
 import org.mule.api.MuleMessage;
 import org.mule.api.expression.ExpressionEvaluator;
+import org.mule.transformer.types.TypedValue;
 
 /**
  * Looks up the property on the message using the property name given.  If the call on the messgae returns null,
@@ -31,6 +28,12 @@ public class MessageHeaderExpressionEvaluator implements ExpressionEvaluator
         return ExpressionUtils.getPropertyWithScope(expression, message);
     }
 
+    @Override
+    public TypedValue evaluateTyped(String expression, MuleMessage message)
+    {
+        return ExpressionUtils.getTypedProperty(expression, message);
+    }
+
     /**
      * {@inheritDoc}
      */
@@ -39,11 +42,4 @@ public class MessageHeaderExpressionEvaluator implements ExpressionEvaluator
         return NAME;
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public void setName(String name)
-    {
-        throw new UnsupportedOperationException();
-    }
 }
