@@ -1,8 +1,5 @@
 /*
- * $Id$
- * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
- *
  * The software in this package is published under the terms of the CPAL v1.0
  * license, a copy of which has been included with this distribution in the
  * LICENSE.txt file.
@@ -36,7 +33,10 @@ import org.guiceyfruit.mule.MuleModule;
  * Note for better performance, any basepath set should be qualified to your application. For example, if your application
  * has a package com.mycompany.app, its better to set the base path to 'com/mycompany/app' over 'com/' or '/' since they will
  * search everything on the classpath that matches the specified package.
+ *
+ * @deprecated Guice module is deprecated and will be removed in Mule 4.
  */
+@Deprecated
 public class GuiceConfigurationBuilder extends AbstractConfigurationBuilder
 {
     public static final String DEFAULT_PACKAGE = "";
