@@ -1,13 +1,9 @@
 /*
- * $Id: MuleSendActivity.java 20121 2010-11-08 17:33:48Z tcarlson $
- * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
- *
  * The software in this package is published under the terms of the CPAL v1.0
  * license, a copy of which has been included with this distribution in the
  * LICENSE.txt file.
  */
-
 package org.mule.module.jbpm;
 
 import org.mule.MessageExchangePattern;
@@ -59,11 +55,6 @@ public class MuleSendActivity extends JpdlActivity implements EventListener
      */
     private String payloadExpression;
 
-    /**
-     * The actual payload (as an object) will be stored here.
-     */
-    private Object payloadObject;
-    
     private static final Log log = Log.getLog(MuleSendActivity.class.getName());
 
     public void execute(ActivityExecution execution) throws Exception
@@ -85,6 +76,7 @@ public class MuleSendActivity extends JpdlActivity implements EventListener
             throw new JbpmException("The Mule MessageService is not available from the ProcessEngine, you may need to add it to your jbpm.cfg.xml file");
         }
 
+        Object payloadObject = null;
         if (payloadExpression == null)
         {
             payloadObject = execution.getVariable(Process.PROCESS_VARIABLE_DATA);
