@@ -1,19 +1,15 @@
 /*
- * $Id$
- * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
- *
  * The software in this package is published under the terms of the CPAL v1.0
  * license, a copy of which has been included with this distribution in the
  * LICENSE.txt file.
  */
-
 package org.mule.module.json;
 
 import org.mule.api.MuleMessage;
 import org.mule.api.MuleRuntimeException;
-import org.mule.api.expression.ExpressionEvaluator;
 import org.mule.config.i18n.CoreMessages;
+import org.mule.expression.AbstractExpressionEvaluator;
 import org.mule.util.NumberUtils;
 
 import java.util.ArrayList;
@@ -63,7 +59,7 @@ import org.codehaus.jackson.node.ValueNode;
  *
  * @see org.mule.module.json.JsonData
  */
-public class JsonExpressionEvaluator implements ExpressionEvaluator
+public class JsonExpressionEvaluator extends AbstractExpressionEvaluator
 {
     /**
      * logger used by this class
