@@ -1,13 +1,9 @@
 /*
- * $Id: DescriptorParser.java 19191 2010-08-25 21:05:23Z tcarlson $
- * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
- *
  * The software in this package is published under the terms of the CPAL v1.0
  * license, a copy of which has been included with this distribution in the
  * LICENSE.txt file.
  */
-
 package org.mule.module.launcher.descriptor;
 
 import java.io.File;
@@ -18,7 +14,7 @@ import java.io.IOException;
  */
 public interface DescriptorParser
 {
-    ApplicationDescriptor parse(File descriptor) throws IOException;
+    ApplicationDescriptor parse(File descriptor, String applicationName) throws IOException;
 
     String getSupportedFormat();
 }
