@@ -1,15 +1,13 @@
 /*
- * $Id: SftpConnector.java 22029 2011-05-30 14:43:18Z dfeist $
- * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
- *
  * The software in this package is published under the terms of the CPAL v1.0
  * license, a copy of which has been included with this distribution in the
  * LICENSE.txt file.
  */
-
 package org.mule.transport.sftp;
 
+import static org.mule.transport.sftp.AuthenticationMethodValidator.validateAuthenticationMethods;
+
 import org.mule.api.MuleContext;
 import org.mule.api.MuleException;
 import org.mule.api.construct.FlowConstruct;
@@ -56,6 +54,7 @@ public class SftpConnector extends AbstractConnector
     public static final String PROPERTY_INCLUDE_SUBFOLDERS = "includeSubfolders";
     public static final String PROPERTY_IDENTITY_FILE = "identityFile";
     public static final String PROPERTY_PASS_PHRASE = "passphrase";
+    public static final String PROPERTY_KNOWN_HOSTS_FILE = "knownHostsFile";
     public static final String PROPERTY_FILE_AGE = "fileAge";
     public static final String PROPERTY_TEMP_DIR = "tempDir";
     public static final String PROPERTY_SIZE_CHECK_WAIT_TIME = "sizeCheckWaitTime";
@@ -66,6 +65,7 @@ public class SftpConnector extends AbstractConnector
     public static final String PROPERTY_USE_TEMP_FILE_TIMESTAMP_SUFFIX = "useTempFileTimestampSuffix";
     public static final String PROPERTY_DUPLICATE_HANDLING_THROW_EXCEPTION = "throwException";
     public static final String PROPERTY_DUPLICATE_HANDLING_OVERWRITE = "overwrite";
+    public static final String PROPERTY_DUPLICATE_HANDLING_APPEND = "append";
     public static final String PROPERTY_DUPLICATE_HANDLING_ASS_SEQ_NO = "addSeqNo";
     public static final String PROPERTY_MAX_CONNECTION_POOL_SIZE = "maxConnectionPoolSize";
     public static final String PROPERTY_KEEP_FILE_ON_ERROR = "keepFileOnError";
@@ -86,6 +86,8 @@ public class SftpConnector extends AbstractConnector
     private String identityFile;
     private String passphrase;
 
+    private String knownHostsFile;
+
     private boolean checkFileAge = false;
     private long fileAge = 0;
 
@@ -100,6 +102,7 @@ public class SftpConnector extends AbstractConnector
     private String archiveDir = "";
     private String archiveTempReceivingDir = "";
     private String archiveTempSendingDir = "";
+    private String preferredAuthenticationMethods;
 
     /**
      * Should the file be kept if an error occurs when writing the file on the
@@ -140,11 +143,13 @@ public class SftpConnector extends AbstractConnector
         filenameParser = new ExpressionFilenameParser();
     }
 
+    @Override
     public String getProtocol()
     {
         return "sftp";
     }
 
+    @Override
     public MessageReceiver createReceiver(FlowConstruct flow, InboundEndpoint endpoint) throws Exception
     {
         long polling = pollingFrequency;
@@ -165,7 +170,7 @@ public class SftpConnector extends AbstractConnector
             logger.debug("Set polling frequency to: " + polling);
         }
 
-        return serviceDescriptor.createMessageReceiver(this, flow, endpoint, new Object[]{polling});
+        return serviceDescriptor.createMessageReceiver(this, flow, endpoint, new Object[] {polling});
     }
 
     public SftpClient createSftpClient(ImmutableEndpoint endpoint) throws Exception
@@ -187,7 +192,7 @@ public class SftpConnector extends AbstractConnector
             }
             else
             {
-                client = SftpConnectionFactory.createClient(endpoint);
+                client = SftpConnectionFactory.createClient(endpoint, preferredAuthenticationMethods);
             }
 
             // We have to set the working directory before returning
@@ -235,14 +240,21 @@ public class SftpConnector extends AbstractConnector
             }
             else
             {
-                if (client != null && client.isConnected())
+                if (client != null)
                 {
-                    ObjectPool pool = getClientPool(endpoint);
                     if (logger.isDebugEnabled())
                     {
                         logger.debug("Releasing connection for endpoint " + endpoint.getEndpointURI());
                     }
-                    pool.returnObject(client);
+                    if (!client.isConnected())
+                    {
+                        doDestroyClient(endpoint, client);
+                    }
+                    else
+                    {
+                        ObjectPool pool = getClientPool(endpoint);
+                        pool.returnObject(client);
+                    }
                 }
             }
         }
@@ -256,14 +268,19 @@ public class SftpConnector extends AbstractConnector
     {
         if (useConnectionPool())
         {
-            if ((client != null) && (client.isConnected()))
+            if (client != null)
             {
-                ObjectPool pool = getClientPool(endpoint);
-                pool.invalidateObject(client);
+                doDestroyClient(endpoint, client);
             }
         }
     }
 
+    protected void doDestroyClient(ImmutableEndpoint endpoint, SftpClient client) throws Exception
+    {
+        ObjectPool pool = getClientPool(endpoint);
+        pool.invalidateObject(client);
+    }
+
     protected synchronized ObjectPool getClientPool(ImmutableEndpoint endpoint)
     {
         GenericObjectPool pool = pools.get(endpoint.getEndpointURI());
@@ -275,7 +292,9 @@ public class SftpConnector extends AbstractConnector
                 logger.debug("Pool is null - creating one for endpoint " + endpoint.getEndpointURI()
                              + " with max size " + getMaxConnectionPoolSize());
             }
-            pool = new GenericObjectPool(new SftpConnectionFactory(endpoint), getMaxConnectionPoolSize());
+            SftpConnectionFactory factory = new SftpConnectionFactory(endpoint);
+            factory.setPreferredAuthenticationMethods(preferredAuthenticationMethods);
+            pool = new GenericObjectPool(factory, getMaxConnectionPoolSize());
             pool.setTestOnBorrow(isValidateConnections());
             pools.put(endpoint.getEndpointURI(), pool);
         }
@@ -295,6 +314,7 @@ public class SftpConnector extends AbstractConnector
      * (non-Javadoc)
      * @see org.mule.transport.AbstractConnector#doConnect()
      */
+    @Override
     protected void doConnect() throws Exception
     {
         // Do nothing!
@@ -304,6 +324,7 @@ public class SftpConnector extends AbstractConnector
      * (non-Javadoc)
      * @see org.mule.transport.AbstractConnector#doDisconnect()
      */
+    @Override
     protected void doDisconnect() throws Exception
     {
         // Do nothing!
@@ -313,6 +334,7 @@ public class SftpConnector extends AbstractConnector
      * (non-Javadoc)
      * @see org.mule.transport.AbstractConnector#doDispose()
      */
+    @Override
     protected void doDispose()
     {
         // Do nothing!
@@ -322,6 +344,7 @@ public class SftpConnector extends AbstractConnector
      * (non-Javadoc)
      * @see org.mule.transport.AbstractConnector#doInitialise()
      */
+    @Override
     protected void doInitialise() throws InitialisationException
     {
         if (filenameParser != null)
@@ -334,6 +357,7 @@ public class SftpConnector extends AbstractConnector
      * (non-Javadoc)
      * @see org.mule.transport.AbstractConnector#doStart()
      */
+    @Override
     protected void doStart() throws MuleException
     {
         // Do nothing!
@@ -343,6 +367,7 @@ public class SftpConnector extends AbstractConnector
      * (non-Javadoc)
      * @see org.mule.transport.AbstractConnector#doStop()
      */
+    @Override
     protected void doStop() throws MuleException
     {
         if (logger.isDebugEnabled())
@@ -430,6 +455,16 @@ public class SftpConnector extends AbstractConnector
         this.passphrase = passphrase;
     }
 
+    public String getKnownHostsFile()
+    {
+        return knownHostsFile;
+    }
+
+    public void setKnownHostsFile(String knownHostsFile)
+    {
+        this.knownHostsFile = knownHostsFile;
+    }
+
     /**
      * Returns the file age.
      * 
@@ -476,13 +511,6 @@ public class SftpConnector extends AbstractConnector
         tempDirOutbound = pTempDirOutbound;
     }
 
-    // Need this method to be public for SftpNotifier
-    @Override
-    public boolean isEnableMessageEvents()
-    {
-        return super.isEnableMessageEvents();
-    }
-
     public void setDuplicateHandling(String duplicateHandling)
     {
         this.duplicateHandling = duplicateHandling;
@@ -574,4 +602,34 @@ public class SftpConnector extends AbstractConnector
     {
         keepFileOnError = pKeepFileOnError;
     }
+
+    public String getPreferredAuthenticationMethods()
+    {
+        return preferredAuthenticationMethods;
+    }
+
+    public void setPreferredAuthenticationMethods(String preferredAuthenticationMethods)
+    {
+        validateAuthenticationMethods(preferredAuthenticationMethods);
+        
+        this.preferredAuthenticationMethods = preferredAuthenticationMethods;
+    }
+
+
+    //Since SFTP does not have any connection at the connector level and
+    //since we need to fix SFTP connection at the inbound level we just let
+    //each receiver to do it's own reconnection.
+    @Override
+    public void connect() throws Exception
+    {
+        setConnected(true);
+        connectConnectorAndReceivers();
+    }
+
+
+    @Override
+    public void disconnect() throws Exception
+    {
+        setConnected(false);
+    }
 }
